colour.models.dataset.ekta_space_ps5 Module — Colour 0.3.0 documentation

# colour.models.dataset.ekta_space_ps5 Module

## Ekta Space PS 5 Colourspace

Defines the Ekta Space PS 5 colourspace:

- `EKTA_SPACE_PS_5_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.josephholmes.com/Ekta_Space.zip (Last accessed 13 April 2014)

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_PRIMARIES` = array([[ 0.69473684, 0.30526316], [ 0.26 , 0.7 ], [ 0.10972851, 0.00452489]])

  Ekta Space PS 5 colourspace primaries.

  EKTA_SPACE_PS_5_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_WHITEPOINT` = (0.34567, 0.3585)

  Ekta Space PS 5 colourspace whitepoint.

  EKTA_SPACE_PS_5_WHITEPOINT : tuple

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_TO_XYZ_MATRIX` = array([[ 5.94225061e-01, 2.72962901e-01, 9.70240322e-02], [ 2.61098890e-01, 7.34900119e-01, 4.00099102e-03], [ 4.74800172e-17, 4.19942925e-02, 7.83193992e-01]])

  Ekta Space PS 5 colourspace to CIE XYZ colourspace matrix.

  EKTA_SPACE_PS_5_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.ekta_space_ps5.` `XYZ_TO_EKTA_SPACE_PS_5_MATRIX` = array([[ 2.00374294, -0.73027606, -0.24449803], [-0.71210742, 1.62065826, 0.07993842], [ 0.03818268, -0.08689852, 1.27253663]])

  CIE XYZ colourspace to Ekta Space PS 5 colourspace matrix.

  XYZ_TO_EKTA_SPACE_PS_5_MATRIX : array_like, (3, 3)

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Ekta Space PS 5 colourspace.

  EKTA_SPACE_PS_5_TRANSFER_FUNCTION : object

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Ekta Space PS 5 colourspace to linear.

  EKTA_SPACE_PS_5_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.ekta_space_ps5.` `EKTA_SPACE_PS_5_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e24290>

  Ekta Space PS 5 colourspace.

  EKTA_SPACE_PS_5_COLOURSPACE : RGB_Colourspace